@@ -24,8 +24,8 @@ class HomeServices:
         return self.app
 
     def run(self):
-        # self.app.run()
-        self.app.run(host='0.0.0.0', port=5000)
+        self.app.run()
+        #self.app.run(host='0.0.0.0')
 
     def index(self):
         return 'This is the Pi server.'
